SystemOrganization addCategory: #'Limbo-Tests'!

TestCase subclass: #LimboTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Limbo-Tests'

	classInstanceVariableNames:''!

!LimboTest methodsFor: 'tests' stamp: 'MML 11/15/2012 16:07'!
testBasicCommand
	| arg limbo |
	arg := 'this is a test string', String crlf, 'with new lines'.
	self
		shouldnt: [ limbo := Limbo run: '/bin/echo' arguments: { arg } ]
		raise: LimboError.
		
	self assert: limbo notNil.
	self assert: limbo errorString isEmpty.
	self assert: limbo outString equals: arg, String lf! !

!LimboTest methodsFor: 'tests' stamp: 'MML 11/15/2012 15:22'!
testBasicShellCommand
	| arg limbo |
	arg := 'this is a test string'.
	self
		shouldnt: [ limbo := Limbo runSh: '/bin/echo ', arg  ]
		raise: LimboError.
		
	self assert: limbo errorString isEmpty.
	self assert: limbo outString equals: arg, String lf! !

!LimboTest methodsFor: 'tests' stamp: 'MML 11/19/2012 18:29'!
testCommandWithErrors
	| arg limbo |
	arg := 'foo'.
	self
		shouldnt: [ limbo := Limbo run: '/bin/cat' arguments: { arg } ]
		raise: LimboError.
		
	self assert: limbo notNil.
	self assert: limbo outString isEmpty.
	self deny: limbo errorString isEmpty.
	self assert: limbo errorString equals: 'cat: foo: No such file or directory', String lf! !

!LimboTest methodsFor: 'tests' stamp: 'MML 11/19/2012 18:54'!
testComplicatedCommand
	| limbo echo sed |
	limbo := Limbo run: '/usr/bin/which' arguments: { 'echo' }.
	self assert: limbo succeeded.
	echo := limbo outString allButLast.
	
	limbo := Limbo run: '/usr/bin/which' arguments: { 'sed' }.
	self assert: limbo succeeded.
	sed := limbo outString allButLast.
	
	limbo := Limbo runSh: echo, ' day | ', sed, ' s/day/night/'.
	self assert: limbo succeeded.
	self assert: limbo errorString isEmpty.
	self deny: limbo outString isEmpty.
	self assert: limbo outString equals: 'night', String lf! !

!LimboTest methodsFor: 'tests' stamp: 'MML 11/19/2012 18:28'!
testShellCommandWithErrors
	"passing a new line to /bin/sh will cause it to think that the arguments list is finished"
	| arg limbo |
	arg := 'this is a test string', String crlf, 'with new lines'.
	self
		shouldnt: [ limbo := Limbo runSh: '/bin/echo ' , arg  ]
		raise: LimboError.
		
	self deny: limbo errorString isEmpty.
	self assert: limbo errorString equals: '/bin/sh: line 1: with: command not found', String lf! !

!LimboTest methodsFor: 'tests' stamp: 'MML 11/19/2012 19:00'!
testStringArgument
	self
		should: [ Limbo run: 'foo' arguments: 'bar' ]
		raise: LimboError
		whoseDescriptionIncludes: 'expected collection of strings'
		description: 'expected an error because of the arguments being a string instead of a collection of strings'! !

!LimboTest methodsFor: 'tests' stamp: 'MML 11/19/2012 18:56'!
testSuccess
	| limbo |
	limbo := Limbo run: '/bin/cat' arguments: { 'foo' }.
	self deny: limbo succeeded.
	self deny: limbo command exitStatus isZero.
	self assert: limbo outString isEmpty.
	self deny: limbo errorString isEmpty! !
